@@ -1,4 +1,5 @@
 from playscii import GameManager, GameObject
+from playscii.input import Input
 from threading import Timer
 from random import randint
 
@@ -14,11 +15,8 @@ WIDTH, HEIGHT, SPEED, ENEMY_SPEED = 50, 25, 30, 5
 
 
 class GalagaManager(GameManager):
-    def __init__(self, gyro, button, led):
+    def __init__(self):
         super().__init__((WIDTH, HEIGHT))
-        self.gyro = gyro
-        self.button = button
-        self.led = led
         self.time = 0
         self.jet = Jet(pos=(WIDTH // 2, 3))
         self.cooling = False
@@ -32,7 +30,6 @@ class GalagaManager(GameManager):
         self.time = 0
         self.add_object(self.jet)
         self.set_title("Galaga with PyMODI")
-        self.led.set_green()
         self.add_object(self.scoreboard)
 
     def update(self):
@@ -42,19 +39,18 @@ class GalagaManager(GameManager):
             self.time = 0
             self.spawn_enemy()
         self.scoreboard.render = str(self.score)
-        pitch = self.gyro.get_pitch()
-        if pitch < 5 and self.jet.x < self.width - self.jet.width:
+
+        if Input.get_key('right') and self.jet.x < self.width - self.jet.width:
             self.jet.x += SPEED * self.delta_time
-        elif pitch > 5 and self.jet.x > 0:
+        elif Input.get_key('left') and self.jet.x > 0:
             self.jet.x -= SPEED * self.delta_time
-        if self.button.get_pressed():
+        if Input.get_key('space'):
             if not self.cooling:
                 self.cooling = True
                 self.jet.shoot(self)
                 Timer(0.2, self.cool_off).start()
         if self.jet.check_death(self.enemies):
             self.set_title("GAME OVER")
-            self.led.set_rgb(255, 0, 0)
             self.quit()
             return
         self.clean_enemies()
